@@ -52,7 +52,7 @@ class apic():
 			headers = {}
 			print ( requests.request("POST", AuthURL, headers=headers, verify=verifySSL, auth=(self.uid, self.pw), timeout=timeout))
 			try:
-				print ("Authenticating...")
+				print("Authenticating...")
 				response = requests.request("POST", AuthURL, headers=headers, verify=verifySSL, auth=(self.uid, self.pw), timeout=timeout)
 			except:
 				print("Error: Timeout connection to DNA-C. Most likely a network reachability issue")
@@ -350,13 +350,13 @@ class apic():
 					if project['name'] == projectName:
 						projectExists = True
 						projectId = project['id']
-						print ("project exists: " + projectName + " - " + projectId)		
+						print ("Project exists: " + projectName + " - " + projectId)		
 
 						for templates in project['templates']:
 							if templates['name'] == templateName:
 								templateId = templates['id']
 								templateExists = True
-								print ("template finns: " + templateName + " - " + templateId)
+								print ("Template exists: " + templateName + " - " + templateId)
 
 
 				if projectExists == False:
@@ -403,7 +403,20 @@ class apic():
 
 				if templateExists == True:
 				#Since the template exists, PUT the file from directory to make sure the active template is same version.
-					print ("Template " + templateName + " already exists, updating.")
+					print ("Template " + templateName + " already exists, versioning and updating.")
+
+					headers = {
+				  	'x-auth-token': self.authToken,
+					'Content-Type': 'application/json',
+					}
+
+					versionUrl = "https://" + self.ip + ":" + self.port + baseurl + "template-programmer/template/version"
+					versionPayload = {
+					'comments': 'Updated with EZDNAC', 
+					'templateId': templateId
+					}
+					requests.post(versionUrl, headers=headers, json=versionPayload, verify=verifySSL)
+					
 					url = "https://" + self.ip + ":" + self.port + baseurl + "template-programmer/template/"
 					payload = templateFile
 					payload['id'] = templateId
@@ -413,10 +426,7 @@ class apic():
 
 					payload['templateContent'] = templateContents
 
-					headers = {
-				  	'x-auth-token': self.authToken,
-					'Content-Type': 'application/json',
-					}
+
 					response = requests.request("PUT", url, headers=headers, json=payload, verify=verifySSL)
 					data = json.loads(response.text)
 
